# TODO unbundled mimalloc and libdxfrw
# FIXME re-enable debuginfo
%global debug_package %{nil}

%define major     1
%define libname   %mklibname slvs %{major}
%define develname %mklibname slvs -d

Name:           solvespace
Version:        3.1
Release:        %mkrel 3
Summary:        SolveSpace parametric 2d/3d CAD
License:        GPLv3
Group:          Graphics/3D
Url:            https://solvespace.com/
Source0:        https://github.com/solvespace/solvespace/releases/download/v%{version}/%{name}-%{version}.tar.xz
Patch0:         solvespace-cmake-4.0.patch

BuildRequires:  cmake
BuildRequires:  pangomm-devel
BuildRequires:  pkgconfig(appstream-glib)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(spnav)
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(libdxfrw)
BuildRequires:  pkgconfig(mimalloc)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(zlib)

%description
SolveSpace is a parametric 2d/3d CAD program. Applications include:
* modeling 3d parts - draw with extrudes, revolves, and Boolean
  (union / difference) operations;
* modeling 2d parts - draw the part as a single section, and export DXF,
  PDF, SVG; use 3d assembly to verify fit;
* 3d-printed parts - export the STL or other triangle mesh expected by
  most 3d printers;
* preparing CAM data - export 2d vector art for a waterjet machine or
  laser cutter; or generate STEP or STL, for import into third-party
  CAM software for machining;
* mechanism design - use the constraint solver to simulate planar or
  spatial linkages, with pin, ball, or slide joints;
* plane and solid geometry - replace hand-solved trigonometry and
  spreadsheets with a live dimensioned drawing.

%package -n %{libname}
Summary:        SolveSpace geometric kernel
Group:          System/Libraries

Obsoletes:      %{_lib}slvs < 3.1-2

%description -n %{libname}
SolveSpace is a parametric 2d/3d CAD. libslvs contains the geometric
kernel of SolveSpace, built as a library.

%package -n %{develname}
Summary:        SolveSpace geometric kernel (development files)
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       slvs-devel = %{version}-%{release}

%description -n %{develname}
SolveSpace is a parametric 2d/3d CAD. libslvs contains the geometric
kernel of SolveSpace, built as a library.

This package includes development files for libslvs.

%prep
%autosetup -p1
sed \
-e "s/include(GetGitCommitHash)/#/" \
-e "s/# set(GIT_COMMIT_HASH/set(GIT_COMMIT_HASH/" -i CMakeLists.txt

%build
%cmake \
    -DENABLE_OPENMP=ON
%cmake_build

%install
%cmake_install

%check
appstream-util validate-relax --nonet %{buildroot}%{_metainfodir}/*.metainfo.xml

%files
%doc README.md wishlist.txt
%license COPYING.txt
%_bindir/%name
%_bindir/%name-cli
%_iconsdir/hicolor/*/apps/%name.png
%_iconsdir/hicolor/*/apps/%name.svg
%_iconsdir/hicolor/*/mimetypes/application-x-solvespace.png
%_iconsdir/hicolor/*/mimetypes/application-x-solvespace.svg
%_datadir/applications/%name.desktop
%_datadir/mime/packages/solvespace-slvs.xml
%_metainfodir/com.solvespace.SolveSpace.metainfo.xml
%_datadir/%name/

%files -n %{libname}
%_libdir/libslvs.so.%{major}
%_libdir/libslvs.so.%{version}

%files -n %{develname}
%_libdir/libslvs.so
%_includedir/slvs.h


%changelog
* Fri Jul 04 2025 daviddavid <daviddavid> 3.1-3.mga10
+ Revision: 2244989
- fix build with cmake 4.0
+ umeabot <umeabot>
- Mageia 10 Mass Rebuild

* Sat Apr 08 2023 daviddavid <daviddavid> 3.1-2.mga9
+ Revision: 1951721
- fix library pkg name
- switch BRs to pkgconfig()
- fix devel sub-pkg dependencies and add virtual provides

* Fri Apr 07 2023 papoteur <papoteur> 3.1-1.mga9
+ Revision: 1951679
- imported package solvespace

